@@ -187,8 +187,9 @@ class Queue(object):
 
             method, header_frame, body = self.channel.basic_get(queue=queue_name)
 
-
-            if method.NAME == 'Basic.GetEmpty':
+            # Pika changed the API for this. For Basic.GetEmpty
+            # they now return None, None, None
+            if method is None and header_frame is None and body is None:
                 if self.finish_on_empty is True:
                     keep_reading = False
                     self.logger.debug("Queue empty, leaving!")
